==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Classes/Axios/Fetcher/AxiosFetcher.js <==
import Axios from "./../Axios";
import AxiosFetcherSearch from "./AxiosFetcherSearch"
import AxiosFetcherOrder from "./AxiosFetcherOrder"
import AxiosFetcherConditions from "./AxiosFetcherConditions";
import AxiosFetcherFilters from "./AxiosFetcherFilters"

/***************
 * AxiosFetcher
 ***************
 * - extract records from DB
 ****************************************/

class AxiosFetcher extends Axios {

    
    constructor() {
        super()

        this.processing = true
        /**
         * current_page:integer - Pagina curenta
         */
        this.current_page = 1

        /**
         * per_page:integer - Numar de inregistrari pe pagina 
         */
        this.per_page = null

        /**
         * conditions:AxiosFetcherConditions - conditii pentru filtrare
         */
        this.conditions = new _AxiosFetcherConditions__WEBPACK_IMPORTED_MODULE_3__["default"]()

        /**
         * search:AxiosFetcherSearch - coloane pentru cautare
         */
        this.search = new _AxiosFetcherSearch__WEBPACK_IMPORTED_MODULE_1__["default"]()

        /**
         * order:AxiosFetcherOrder - coloane pentru sortare
         */
        this.order = new _AxiosFetcherOrder__WEBPACK_IMPORTED_MODULE_2__["default"]()

        /**
         * filters:AxiosFetcherFilters - conditii pentru filtrare
         */
        this.filters = new _AxiosFetcherFilters__WEBPACK_IMPORTED_MODULE_4__["default"]()

        this.refresh_count = 0

    }

    set endpoint(value) {
        this._endpoint = value
    }

    get endpoint() {
        if( ! this._endpoint)
        {
            return null
        }
        return ((this._endpoint.substr(0,4) === 'http') ? '' : this.url + '/') + this._endpoint + '?page=' + this.current_page 
    }
    
    get fetcherData() {
        return {
            per_page: this.per_page,
            searchable: this.search.searchable,
            orderable: this.order.currentOrder,
            conditions: this.conditions.conditions,
            filters: this.filters.filterConditions,
        }
    }

    get records() {
        return this.response ? this.response.paginator.data : []
    }

    get from() {
        return this.response ? this.response.paginator.from : null
    }

    get to() {
        return this.response ? this.response.paginator.to : null
    }

    get last_page() {
        return this.response ? this.response.paginator.last_page : null
    }

    get total() {
        return this.response ? this.response.paginator.total : null
    }

    get record_count() {
        return this.response ? this.response.record_count : null
    }

    get real_record_count() {
        let filtered = this.filterProperties ? this.filterProperties.count : 0
        return Math.min(filtered, this.record_count || 0)
    }

    get orderProperties() {
        return this.response ? this.response.orders : null
    }

    get searchProperties() {
        return this.response ? this.response.searches : null
    }

    get conditionsProperties() {
        return this.response ? this.response.conditions : null
    }

    get filterProperties() {
        return this.response ? this.response.filters : null
    }

    get currentOrder() {
        return this.order.current_order
    }

    get currentDirection() {
        return this.currentOrder ? this.order.columns.All()[this.currentOrder].direction : null
    }

    get searchedValue() {
        return this.search.value
    }

    get filteredRecordsCount() {
        return this.conditionsProperties ? this.conditionsProperties.count : 0
    }

    /**
     * Proprietate calculata
     * true, daca nu avem inregistrari returnate de request
     *      - nu este in procesare (! this.processing)
     *      - avem filters in response (this.filterProperties)
     *      - numar inregistrari in filters este 0 (fetcher.filterProperties.count == 0)
     */
    get has_no_records() {
        return (! this.processing) && this.filterProperties && (this.filterProperties.count == 0)
    }

    /**
     * Proprietate calculata
     * true, daca utilizatorul cauta in Quick Search si nu obtine recorduri
     *      - nu este in procesare (! this.processing)
     *      - avem valoare cautata in request (this.searchedValue)
     *      - avem searches in response (this.searchProperties)
     *      - numar inregistrari in searches este 0 (fetcher.searchProperties.count == 0)
     */
    get has_no_searched_records() {
        return (! this.processing) && this.searchedValue && this.searchProperties && (this.searchProperties.count == 0)
    }

    /**
     * Proprietate calculata
     * true, daca utilizatorul filtreaza cu formularul si nu obtine recorduri
     */
    get has_no_conditions_records() {
        let wheres_count = this.conditionsProperties ? _.keys(this.conditionsProperties.wheres).length : 0
        return (! this.processing) && wheres_count && (this.conditionsProperties.count == 0)
    }

    SetCurrentPage(value) {
        this.current_page = value
        return this
    }

    SetPerPage(value) {
        this.per_page = value
        return this
    }

    SetSearchFields(values) {
        this.search.SetFields(values)
        return this
    }

    AddOrderColumn(column, fields) {
        this.order.AddOrderColumn(column, fields)
        return this
    }

    AddCondition(name, column, type) {
        this.conditions.AddCondition(name, column, type)
        return this
    }

    AddFilter(key, where, values) {
        this.filters.Add(key, where, values)
        return this
    }

    /**
     * Methods
     */
    ChangePage(page) {
        this.SetCurrentPage(page)
        this.Refresh()
    }

    Search(value = null) {
        this.search.value = value
        this.SetCurrentPage(1)
        this.Refresh()
    }

    Order(column, direction) {
        this.order.Order(column, direction)
        this.Refresh()
    }

    Condition(name, current_operator, data) {
        this.conditions.Condition(name, current_operator, data)
        this.SetCurrentPage(1)
        this.Refresh()
    }

    SetFilterValue(key, property, value) {
        this.filters.filters.items[key].values[property] = value
        this.SetCurrentPage(1)
        this.Refresh()
    }

    ResetConditions() {
        this.conditions.ResetConditions()
        this.Refresh()
    }

    ChangePageLength(value) {
        this.SetPerPage(value)
        this.SetCurrentPage(1)
        this.Refresh()
    }

    Refresh() {
        this.SetData(this.fetcherData)        
        super.Post()
    }
    
}

export default AxiosFetcher

==> comptechsoft-vue-foundation-1.0.12.tgz: package/src/~compvuetech/Classes/Axios/Fetcher/AxiosFetcher.js <==
import Axios from "./../Axios";
import AxiosFetcherSearch from "./AxiosFetcherSearch"
import AxiosFetcherOrder from "./AxiosFetcherOrder"
import AxiosFetcherConditions from "./AxiosFetcherConditions";
import AxiosFetcherFilters from "./AxiosFetcherFilters"

/***************
 * AxiosFetcher
 ***************
 * - extract records from DB
 ****************************************/

class AxiosFetcher extends Axios {

    
    constructor() {
        super()

        this.processing = true
        /**
         * current_page:integer - Pagina curenta
         */
        this.current_page = 1

        /**
         * per_page:integer - Numar de inregistrari pe pagina 
         */
        this.per_page = null

        /**
         * conditions:AxiosFetcherConditions - conditii pentru filtrare
         */
        this.conditions = new AxiosFetcherConditions()

        /**
         * search:AxiosFetcherSearch - coloane pentru cautare
         */
        this.search = new AxiosFetcherSearch()

        /**
         * order:AxiosFetcherOrder - coloane pentru sortare
         */
        this.order = new AxiosFetcherOrder()

        /**
         * filters:AxiosFetcherFilters - conditii pentru filtrare
         */
        this.filters = new AxiosFetcherFilters()

        this.refresh_count = 0

    }

    set endpoint(value) {
        this._endpoint = value
    }

    get endpoint() {
        if( ! this._endpoint)
        {
            return null
        }
        return ((this._endpoint.substr(0,4) === 'http') ? '' : this.url + '/') + this._endpoint + '?page=' + this.current_page 
    }
    
    get fetcherData() {
        return {
            per_page: this.per_page,
            searchable: this.search.searchable,
            orderable: this.order.currentOrder,
            conditions: this.conditions.conditions,
            filters: this.filters.filterConditions,
        }
    }

    get records() {
        return this.response ? this.response.paginator.data : []
    }

    get from() {
        return this.response ? this.response.paginator.from : null
    }

    get to() {
        return this.response ? this.response.paginator.to : null
    }

    get last_page() {
        return this.response ? this.response.paginator.last_page : null
    }

    get total() {
        return this.response ? this.response.paginator.total : null
    }

    get record_count() {
        return this.response ? this.response.record_count : null
    }

    get real_record_count() {
        let filtered = this.filterProperties ? this.filterProperties.count : 0
        return Math.min(filtered, this.record_count || 0)
    }

    get orderProperties() {
        return this.response ? this.response.orders : null
    }

    get searchProperties() {
        return this.response ? this.response.searches : null
    }

    get conditionsProperties() {
        return this.response ? this.response.conditions : null
    }

    get filterProperties() {
        return this.response ? this.response.filters : null
    }

    get currentOrder() {
        return this.order.current_order
    }

    get currentDirection() {
        return this.currentOrder ? this.order.columns.All()[this.currentOrder].direction : null
    }

    get searchedValue() {
        return this.search.value
    }

    get filteredRecordsCount() {
        return this.conditionsProperties ? this.conditionsProperties.count : 0
    }

    /**
     * Proprietate calculata
     * true, daca nu avem inregistrari returnate de request
     *      - nu este in procesare (! this.processing)
     *      - avem filters in response (this.filterProperties)
     *      - numar inregistrari in filters este 0 (fetcher.filterProperties.count == 0)
     */
    get has_no_records() {
        return (! this.processing) && this.filterProperties && (this.filterProperties.count == 0)
    }

    /**
     * Proprietate calculata
     * true, daca utilizatorul cauta in Quick Search si nu obtine recorduri
     *      - nu este in procesare (! this.processing)
     *      - avem valoare cautata in request (this.searchedValue)
     *      - avem searches in response (this.searchProperties)
     *      - numar inregistrari in searches este 0 (fetcher.searchProperties.count == 0)
     */
    get has_no_searched_records() {
        return (! this.processing) && this.searchedValue && this.searchProperties && (this.searchProperties.count == 0)
    }

    /**
     * Proprietate calculata
     * true, daca utilizatorul filtreaza cu formularul si nu obtine recorduri
     */
    get has_no_conditions_records() {
        let wheres_count = this.conditionsProperties ? _.keys(this.conditionsProperties.wheres).length : 0
        return (! this.processing) && wheres_count && (this.conditionsProperties.count == 0)
    }

    SetCurrentPage(value) {
        this.current_page = value
        return this
    }

    SetPerPage(value) {
        this.per_page = value
        return this
    }

    SetSearchFields(values) {
        this.search.SetFields(values)
        return this
    }

    AddOrderColumn(column, fields) {
        this.order.AddOrderColumn(column, fields)
        return this
    }

    AddCondition(name, column, type) {
        this.conditions.AddCondition(name, column, type)
        return this
    }

    AddFilter(key, where, values) {
        this.filters.Add(key, where, values)
        return this
    }

    /**
     * Methods
     */
    ChangePage(page) {
        this.SetCurrentPage(page)
        this.Refresh()
    }

    Search(value = null) {
        this.search.value = value
        this.SetCurrentPage(1)
        this.Refresh()
    }

    Order(column, direction) {
        this.order.Order(column, direction)
        this.Refresh()
    }

    Condition(name, current_operator, data) {
        this.conditions.Condition(name, current_operator, data)
        this.SetCurrentPage(1)
        this.Refresh()
    }

    SetFilterValue(key, property, value) {
        this.filters.filters.items[key].values[property] = value
        this.SetCurrentPage(1)
        this.Refresh()
    }

    ResetConditions() {
        this.conditions.ResetConditions()
        this.Refresh()
    }

    ChangePageLength(value) {
        this.SetPerPage(value)
        this.SetCurrentPage(1)
        this.Refresh()
    }

    Refresh() {
        this.SetData(this.fetcherData)        
        super.Post()
    }
    
}

export default AxiosFetcher
